@@ -1,7 +1,7 @@
 r"""
 pysak is a simple, powerful and clean python common function library.
 
-Github Repositories: https://github.com/1Gbps/pysak
+Github Repository: https://github.com/1Gbps/pysak
 """
 
 SakUserPlatform = None
